@@ -783,62 +783,126 @@ QString PluginKateXMLTools::insideAttribute(Kate::View &kv)
   * <p> <a x="xyz"> foo bar </a> X
   * <p> foo <img/> bar X
   * <p> foo bar X
-  * WARNING (TODO): behaviour undefined if called when cursor is
-  * /inside/ an element!!
   */
-QString PluginKateXMLTools::getParentElement(Kate::View &kv, bool ignore_single_bracket)
+QString PluginKateXMLTools::getParentElement(Kate::View &kv, bool ignore_single_char)
 {
+	enum {
+		parsing_text,
+		parsing_element,
+		parsing_element_boundary,
+		parsing_non_element,
+		parsing_attribute_dquote,
+		parsing_attribute_squote,
+		parsing_ignore
+	}parse_state;
+	parse_state = ignore_single_char ? parsing_ignore : parsing_text;
+	
+	int nesting_level = 0;
 
-	int nesting_level = 1;
-
-	bool in_tag = false;
-	QString tag = "";
-
-	uint line = 0, col = 0;
+	uint line, col;
 	kv.cursorPositionReal(&line, &col);
-	col = col-1;
-	int y = line;	// another variable because uint <-> int
-	int y_prev = y;
-	do {
-		QString line_str = kv.getDoc()->textLine(y);
-		int stop = ignore_single_bracket ? 1 : 0;
-		for( int x = col; x >= stop; x-- ) {
-			QString ch = line_str.mid(x-stop, 1);
-			if( ch == ">" ) {
-				in_tag = true;
-				tag = "";
-			} else if( ch == "<" ) {
-				in_tag = false;
-				if( isEmptyTag("<"+tag+">") ) {
-					// do nothing
-				} else if( isOpeningTag("<"+tag+">") ) {
-					nesting_level--;
-				} else if( isClosingTag("<"+tag+">") ) {
-					nesting_level++;
-				}
-				if( nesting_level <= 0 ) {
-					// cut of everything after the element name:
-					uint elem_count = 0;
-					while( ! tag.at(elem_count).isSpace() && elem_count < tag.length() ) {
-						elem_count++;
-					}
-					QString element = tag.left(elem_count);
-					return element;
-				}
-				// "else": empty tags can be ignored
-			} else if( in_tag == true && y != y_prev ) {
-				tag = ch + tag;		// we're moving left and changing rows
-				y_prev = y;
-			} else if( in_tag == true ) {
-				tag = ch + tag;		// we're moving left!
-			}
+	QString str = kv.getDoc()->textLine(line);
+	
+	while(true) {
+		// move left a character
+		if(!col--) {
+			do {
+				if(!line--) return QString::null; // reached start of document
+				str = kv.getDoc()->textLine(line);
+				col = str.length();
+			}while(!col);
+			--col;
 		}
-		y--;
-		col = kv.getDoc()->textLine(y).length();
-	} while( y >= 0 );
-	// TODO: limit line_count?
-
-	return QString();
+		
+		ushort ch = str.at(col).unicode();
+		
+		switch(parse_state) {
+			case parsing_ignore:
+				parse_state = parsing_text;
+				break;
+				
+			case parsing_text:
+				switch(ch) {
+					case '<':
+						// hmm... we were actually inside an element
+						return QString::null;
+						
+					case '>':
+						// we just hit an element boundary
+						parse_state = parsing_element_boundary;
+						break;
+				}
+				break;
+				
+			case parsing_element:
+				switch(ch) {
+					case '"': // attribute (double quoted)
+						parse_state = parsing_attribute_dquote;
+						break;
+						
+					case '\'': // attribute (single quoted)
+						parse_state = parsing_attribute_squote;
+						break;
+						
+					case '/': // close tag
+						parse_state = parsing_non_element;
+						++nesting_level;
+						break;
+						
+					case '<':
+						// we just hit the start of the element...
+						if(nesting_level--) break;
+						
+						QString tag = str.mid(col + 1);
+						for(uint pos = 0, len = tag.length(); pos < len; ++pos) {
+							ch = tag.at(pos).unicode();
+							if(ch == ' ' || ch == '\t' || ch == '>') {
+								tag.truncate(pos);
+								break;
+							}
+						}
+						return tag;
+				}
+				break;
+				
+			case parsing_element_boundary:
+				switch(ch) {
+					case '?': // processing instruction
+					case '-': // comment
+					case '/': // empty element
+						parse_state = parsing_non_element;
+						break;
+						
+					case '"':
+						parse_state = parsing_attribute_dquote;
+						break;
+						
+					case '\'':
+						parse_state = parsing_attribute_squote;
+						break;
+						
+					case '<': // empty tag (bad XML)
+						parse_state = parsing_text;
+						break;
+						
+					default:
+						parse_state = parsing_element;
+				}
+				break;
+				
+			case parsing_attribute_dquote:
+				if(ch == '"') parse_state = parsing_element;
+				break;
+				
+			case parsing_attribute_squote:
+				if(ch == '\'') parse_state = parsing_element;
+				break;
+				
+			case parsing_non_element:
+				if(ch == '<') parse_state = parsing_text;
+				break;
+		}
+	}
 }
 
 /** Return true if the tag is neither a closing tag
@@ -960,3 +1024,5 @@ QString InsertElement::showDialog(QStringList &completions)
 	}
 	return QString::null;
 }
+
+// kate: replace-tabs false; replace-tabs-save false; space-indent false;
