@@ -1,11 +1,12 @@
-/* $Id: plugin_domtreeviewer.h,v 1.3 2001/10/29 16:32:14 hausmann Exp $ */
+/* $Id: plugin_domtreeviewer.h,v 1.6 2005/02/06 21:56:57 savernik Exp $ */
 
 #ifndef __plugin_domtreeviewer_h
 #define __plugin_domtreeviewer_h
 
 #include <kparts/plugin.h>
-#include <klibloader.h>
+// #include <klibloader.h>
 
+class DOMTreeWindow;
 class KURL;
 
 class PluginDomtreeviewer : public KParts::Plugin
@@ -18,6 +19,9 @@ public:
 
 public slots:
   void slotShowDOMTree();
+  void slotDestroyed();
+private:
+  QGuardedPtr<DOMTreeWindow> m_dialog;
 };
 
 #endif
