@@ -5,7 +5,7 @@
     copyright            : (C) 2001 Joseph Wenninger
     email                : jowenn@kde.org
  ***************************************************************************/
- 
+
 /***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -19,10 +19,12 @@
 #include "mediawidget.moc"
 #include "player.h"
 
+#include <kdebug.h>
 #include <kurl.h>
 #include <kurldrag.h>
 #include <klocale.h>
 
+#include <qlabel.h>
 #include <qwidget.h>
 #include <qpushbutton.h>
 #include <qlcdnumber.h>
@@ -33,28 +35,34 @@
 KSB_MediaWidget::KSB_MediaWidget(QWidget *parent):KSB_MediaWidget_skel(parent)
 {
 	player = new Player(this);
-// player->openFile(KURL("/MP3/CD11/Gigi D'Agostino - Bla bla bla.mp3"));
-// player->openFile(KURL("/home/jowenn/bar1.png"));
-	connect(Play,SIGNAL(clicked()),player,SLOT(play()));
-	connect(Pause,SIGNAL(clicked()),player,SLOT(pause()));
-	connect(Stop,SIGNAL(clicked()),player,SLOT(stop()));
+	empty();
+
+	QFont labelFont = time->font();
+	labelFont.setPointSize(18);
+	labelFont.setBold(true);
+	time->setFont(labelFont);
+
+	connect(Play, SIGNAL(clicked()), player, SLOT(play()));
+	connect(Pause, SIGNAL(clicked()), player, SLOT(pause()));
+	connect(Stop, SIGNAL(clicked()), player, SLOT(stop()));
+
 	connect(player, SIGNAL(timeout()), this, SLOT(playerTimeout()));
 	connect(player, SIGNAL(finished()), this, SLOT(playerFinished()));
+	connect(player, SIGNAL(playing()), this, SLOT(playing()));
+	connect(player, SIGNAL(paused()), this, SLOT(paused()));
+	connect(player, SIGNAL(stopped()), this, SLOT(stopped()));
+	connect(player, SIGNAL(empty()), this, SLOT(empty()));
 
 	connect(Position, SIGNAL(userChanged(int)), this, SLOT(skipToWrapper(int)));
 	connect(this, SIGNAL(skipTo(unsigned long)), player, SLOT(skipTo(unsigned long)));
-// connect(mSeeker, SIGNAL(sliderMoved(int)), this, SLOT(sliderMoved(int)));
-//	connect(Menu,SIGNAL(clicked()),this,SLOT(showMenu()));
 	setAcceptDrops(true);
 
 	pretty="";
 	needLengthUpdate=false;
 
-	QToolTip::add(Play,i18n("Start playing<BR><HR><B><I>Current File</I></B>:"));
-	QToolTip::add(Pause,i18n("Pause playing<BR><HR><B><I>Current File</I></B>:"));
-	QToolTip::add(Stop,i18n("Stop playing<BR><HR><B><I>Current File</I></B>:"));
-	QToolTip::add(Position,i18n("Current playing position<BR><HR><B><I>Current File</I></B>:"));
-	QToolTip::add(time,i18n("Current playing position<BR><HR><I><B>Current File</I></B>:"));
+	QToolTip::add(Play,i18n("Play"));
+	QToolTip::add(Pause,i18n("Pause"));
+	QToolTip::add(Stop,i18n("Stop"));
 }
 
 void KSB_MediaWidget::skipToWrapper(int second)
@@ -92,13 +100,9 @@ void KSB_MediaWidget::playerTimeout()
 		Position->setRange(0, range);
 		if (needLengthUpdate)
 		{
-			QString length=player->lengthString().right(5);
+			int counter = player->lengthString().length() - (player->lengthString().find("/")+1);
+			QString length=player->lengthString().right(counter);
 			needLengthUpdate=false;
-			QToolTip::add(Play,i18n("Start playing<BR><HR><B><I>Current File</I></B>: ")+pretty+i18n("<BR><B><I>Total time</I></B>: ")+length);
-			QToolTip::add(Pause,i18n("Pause playing<BR><HR><B><I>Current File</I></B>: ")+pretty+i18n("<BR><B><I>Total time</I></B>: ")+length);
-			QToolTip::add(Stop,i18n("Stop playing<BR><HR><B><I>Current File</I></B>: ")+pretty+i18n("<BR><B><I>Total time</I></B>: ")+length);
-			QToolTip::add(Position,i18n("Current playing position<BR><HR><B><I>Current File</I></B>: ")+pretty+i18n("<BR><B><I>Total time</I></B>: ")+length);
-			QToolTip::add(time,i18n("Current playing position<BR><HR><B><I>Current File</I></B>: ")+pretty+i18n("<BR><B><I>Total time</I></B>: ")+length);
 		}
 	}
 	else
@@ -106,10 +110,11 @@ void KSB_MediaWidget::playerTimeout()
 		Position->setRange(0, 1);
 	}
 	// set the position
-	Position->setValue((int)(player->getTime() / 1000));	
+	Position->setValue((int)(player->getTime() / 1000));
 
 	// update the time label
-	time->display(player->lengthString().left(5));
+	// catch files with duration > 99mins correctly
+	time->setText(player->lengthString());
 }
 
 void KSB_MediaWidget::playerFinished()
@@ -118,15 +123,47 @@ void KSB_MediaWidget::playerFinished()
 	{
 		KURL kurl = m_kuri_list.first();
 		m_kuri_list.remove( kurl );
-		player->openFile( kurl );
-		player->play();
-		needLengthUpdate=true;
-		pretty=kurl.prettyURL();
-		
-		QToolTip::add(Play,i18n("Start playing<BR><HR><B><I>Current File</I></B>: ")+pretty+i18n("<BR><B><I>Total time</I></B>: "));
-		QToolTip::add(Pause,i18n("Pause playing<BR><HR><B><I>Current File</I></B>: ")+pretty+i18n("<BR><B><I>Total time</I></B>: "));
-		QToolTip::add(Stop,i18n("Stop playing<BR><HR><B><I>Current File</I></B>: ")+pretty+i18n("<BR><B><I>Total time</I></B>: "));
-		QToolTip::add(Position,i18n("Current playing position<BR><HR><B><I>Current File</I></B>: ")+pretty+i18n("<BR><B><I>Total time</I></B>: "));
-		QToolTip::add(time,i18n("Current playing position<BR><HR><B><I>Current File</I></B>: ")+pretty+i18n("<BR><B><I>Total time</I></B>: "));
+		bool validFile = player->openFile( kurl );
+		if (validFile) {
+			currentFile->setText( kurl.filename() );
+			player->play();
+			needLengthUpdate=true;
+			pretty=kurl.prettyURL();
+		} else {
+			currentFile->setText( i18n("Not a sound file") );
+			playerFinished();
+		}
 	}
 }
+
+void KSB_MediaWidget::playing()
+{
+	Play->setEnabled(false);
+	Pause->setEnabled(true);
+	Stop->setEnabled(true);
+}
+
+void KSB_MediaWidget::paused()
+{
+	Play->setEnabled(true);
+	Pause->setEnabled(false);
+	Stop->setEnabled(true);
+}
+
+void KSB_MediaWidget::stopped()
+{
+	Position->setValue(0);
+	time->setText("00:00/00:00");
+	Play->setEnabled(true);
+	Pause->setEnabled(false);
+	Stop->setEnabled(false);
+}
+
+void KSB_MediaWidget::empty()
+{
+	Position->setValue(0);
+	time->setText("00:00/00:00");
+	Play->setEnabled(false);
+	Pause->setEnabled(false);
+	Stop->setEnabled(false);
+}
