@@ -24,7 +24,7 @@
  *  Boston, MA 02111-1307, USA.
  **/
 
-/* $Id: plugin_validators.cpp,v 1.25 2004/06/24 19:44:18 binner Exp $ */
+/* $Id: plugin_validators.cpp,v 1.26 2004/10/25 20:29:03 bmeyer Exp $ */
 
 #include <kinstance.h>
 #include <kmessagebox.h>
@@ -80,7 +80,7 @@ PluginValidators::PluginValidators( QObject* parent, const char* name,
 
       m_part = static_cast<KHTMLPart *>( parent );
       m_configDialog = new ValidatorsDialog( m_part->widget() );
-      this->setURLs();
+      setURLs();
 
       connect( m_part, SIGNAL(started(KIO::Job*)), this,
              SLOT(slotStarted(KIO::Job*)) );
@@ -135,7 +135,7 @@ void PluginValidators::slotValidateLinks()
 void PluginValidators::slotConfigure()
 {
   m_configDialog->show();
-  this->setURLs();
+  setURLs();
 }
 
 void PluginValidators::validateURL(const KURL &url, const KURL &uploadUrl)
