@@ -4,8 +4,8 @@
  *
  *  Copyright (C) 2001 by  Richard Moore <rich@kde.org>
  *                         Andreas Schlapbach <schlpbch@iam.unibe.ch>
- * 
- *  for information how to write your own plugin see:  
+ *
+ *  for information how to write your own plugin see:
  *    http://developer.kde.org/documentation/tutorials/dot/writing-plugins.html
  *
  *  This library is free software; you can redistribute it and/or
@@ -24,7 +24,7 @@
  *  Boston, MA 02111-1307, USA.
  **/
 
-/* $Id: plugin_validators.h,v 1.6.2.1 2003/06/06 17:58:59 faure Exp $ */
+/* $Id: plugin_validators.h,v 1.9 2004/11/17 12:34:02 faure Exp $ */
 
 #ifndef __plugin_validators_h
 #define __plugin_validators_h
@@ -33,6 +33,7 @@
 #include <klibloader.h>
 
 #include "validatorsdialog.h"
+#include <qguardedptr.h>
 
 class KAction;
 class KURL;
@@ -47,23 +48,25 @@ public:
 
 public slots:
   void slotValidateHTML();
-  void slotValidateCSS(); 
+  void slotValidateCSS();
+  void slotValidateLinks();
   void slotConfigure();
 
 private slots:
   void slotStarted( KIO::Job* );
 
-private: 
+private:
   KActionMenu *m_menu;
-  ValidatorsDialog *m_configDialog; // |
+  QGuardedPtr<ValidatorsDialog> m_configDialog; // |
                                     // +-> Order dependency.
   KHTMLPart* m_part;                // |
-  
+
   KURL m_WWWValidatorUrl, m_WWWValidatorUploadUrl;
   KURL m_CSSValidatorUrl, m_CSSValidatorUploadUrl;
+  KURL m_linkValidatorUrl;
 
   void setURLs();
-  void validateURL(const KURL &url, const KURL &uploadUrl);
+  void validateURL(const KURL &url, const KURL &uploadUrl = KURL());
 };
 
 #endif
